commands

package
v0.0.0-...-2323d9c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 2, 2026 License: Apache-2.0 Imports: 14 Imported by: 0

Documentation

Overview

Package commands implements the CLI commands for Thicket.

Index

Constants

This section is empty.

Variables

var ErrTicketNotFound = thickerr.New("ticket not found")

ErrTicketNotFound is returned when a ticket cannot be found. Deprecated: Use thickerr.TicketNotFound() for better error messages.

Functions

func Add

func Add(args []string) error

Add creates a new ticket.

func Close

func Close(args []string) error

Close marks a ticket as closed.

func Comment

func Comment(args []string) error

Comment adds a comment to a ticket.

func Init

func Init(args []string) error

Init initializes a new Thicket project.

func Link(args []string) error

Link creates a dependency between tickets.

func List

func List(args []string) error

List displays tickets.

func Quickstart

func Quickstart(args []string) error

Quickstart prints guidance for coding agents on using Thicket.

func Ready

func Ready(args []string) error

Ready displays the highest priority open ticket that is not blocked by other open tickets.

func Show

func Show(args []string) error

Show displays a single ticket.

func TUI

func TUI(args []string) error

TUI launches the interactive terminal UI.

func Update

func Update(args []string) error

Update modifies an existing ticket.

Types

type InitResponse

type InitResponse struct {
	SuccessResponse
	WorkflowCreated bool `json:"workflow_created"`
}

InitResponse extends SuccessResponse with workflow creation info.

type SuccessResponse

type SuccessResponse struct {
	Success bool   `json:"success"`
	ID      string `json:"id,omitempty"`
	Message string `json:"message,omitempty"`
	Hint    string `json:"hint,omitempty"`
}

SuccessResponse is a common JSON response for mutating commands.

type TicketDetails

type TicketDetails struct {
	Ticket      *ticket.Ticket    `json:"ticket"`
	Comments    []*ticket.Comment `json:"comments"`
	BlockedBy   []*ticket.Ticket  `json:"blocked_by"`
	Blocking    []*ticket.Ticket  `json:"blocking"`
	CreatedFrom *ticket.Ticket    `json:"created_from"`
}

TicketDetails holds all information about a ticket for display.

Jump to