Documentation
¶
Overview ¶
Package commands implements the CLI commands for Thicket.
Index ¶
- Variables
- func Add(args []string) error
- func Close(args []string) error
- func Comment(args []string) error
- func Init(args []string) error
- func Link(args []string) error
- func List(args []string) error
- func Quickstart(args []string) error
- func Ready(args []string) error
- func Show(args []string) error
- func TUI(args []string) error
- func Update(args []string) error
- type InitResponse
- type SuccessResponse
- type TicketDetails
Constants ¶
This section is empty.
Variables ¶
var ErrTicketNotFound = thickerr.New("ticket not found")
ErrTicketNotFound is returned when a ticket cannot be found. Deprecated: Use thickerr.TicketNotFound() for better error messages.
Functions ¶
func Quickstart ¶
Quickstart prints guidance for coding agents on using Thicket.
Types ¶
type InitResponse ¶
type InitResponse struct {
SuccessResponse
WorkflowCreated bool `json:"workflow_created"`
}
InitResponse extends SuccessResponse with workflow creation info.
type SuccessResponse ¶
type SuccessResponse struct {
Success bool `json:"success"`
ID string `json:"id,omitempty"`
Message string `json:"message,omitempty"`
Hint string `json:"hint,omitempty"`
}
SuccessResponse is a common JSON response for mutating commands.
type TicketDetails ¶
type TicketDetails struct {
Ticket *ticket.Ticket `json:"ticket"`
Comments []*ticket.Comment `json:"comments"`
BlockedBy []*ticket.Ticket `json:"blocked_by"`
Blocking []*ticket.Ticket `json:"blocking"`
CreatedFrom *ticket.Ticket `json:"created_from"`
}
TicketDetails holds all information about a ticket for display.
Click to show internal directories.
Click to hide internal directories.